@@ -95,6 +95,7 @@ var flagRules = []linter.FlagRule{
 			"remote-bootstrap-server",
 			"remote-cluster",
 			"enable-systest-events",
+			"encrypted-key-material",
 			"max-partition-memory-bytes",
 			"message-send-max-retries",
 			"request-required-acks",
@@ -142,11 +143,15 @@ var properNouns = []string{
 	"Confluent",
 	"Connect",
 	"Control Center",
+	"Data Encryption Key",
+	"DEK",
 	"Flink",
 	"Go",
 	"Groovy",
 	"Java",
 	"Kafka",
+	"Key Encryption Key",
+	"KEK",
 	"Kotlin",
 	"Ktor",
 	"Node.js",
@@ -192,6 +197,7 @@ var vocabWords = []string{
 	"csharp",
 	"csu",
 	"decrypt",
+	"dek",
 	"deserializer",
 	"deserializers",
 	"dns",
@@ -201,6 +207,7 @@ var vocabWords = []string{
 	"filepath",
 	"flink",
 	"formatter",
+	"gcm",
 	"gcp",
 	"geo",
 	"gzip",
@@ -212,7 +219,9 @@ var vocabWords = []string{
 	"jsonschema",
 	"jwks",
 	"kafka",
+	"kek",
 	"keychain",
+	"kms",
 	"kotlin",
 	"ksql",
 	"ksqldb",
@@ -239,6 +248,7 @@ var vocabWords = []string{
 	"scala",
 	"schemas",
 	"signup",
+	"siv",
 	"springboot",
 	"sql",
 	"ssl",
@@ -249,6 +259,8 @@ var vocabWords = []string{
 	"transactional",
 	"transitgateway",
 	"txt",
+	"undelete",
+	"undeleted",
 	"unregister",
 	"uri",
 	"url",
