@@ -1,10 +1,11 @@
 package auditlog
 
 import (
+	"fmt"
+
 	"github.com/spf13/cobra"
 
 	pcmd "github.com/confluentinc/cli/v3/pkg/cmd"
-	"github.com/confluentinc/cli/v3/pkg/errors"
 	"github.com/confluentinc/cli/v3/pkg/output"
 )
 
@@ -43,7 +44,7 @@ func (c *describeCommand) describe(cmd *cobra.Command, _ []string) error {
 
 	auditLog := user.GetOrganization().GetAuditLog()
 	if auditLog.GetServiceAccountId() == 0 {
-		return errors.New("audit logs are not enabled for this organization")
+		return fmt.Errorf("audit logs are not enabled for this organization")
 	}
 
 	table := output.NewTable(cmd)
