@@ -7,7 +7,6 @@ import (
 
 	pauth "github.com/confluentinc/cli/v3/pkg/auth"
 	pcmd "github.com/confluentinc/cli/v3/pkg/cmd"
-	"github.com/confluentinc/cli/v3/pkg/errors"
 	"github.com/confluentinc/cli/v3/pkg/examples"
 	"github.com/confluentinc/cli/v3/pkg/output"
 	"github.com/confluentinc/cli/v3/pkg/types"
@@ -88,7 +87,7 @@ func getURL(cmd *cobra.Command) (string, error) {
 		return url, nil
 	}
 
-	return "", errors.New("pass the `--url` flag or set the `CONFLUENT_PLATFORM_MDS_URL` environment variable")
+	return "", fmt.Errorf("pass the `--url` flag or set the `CONFLUENT_PLATFORM_MDS_URL` environment variable")
 }
 
 func getCACertPath(cmd *cobra.Command) (string, error) {
