@@ -25,7 +25,7 @@ func (c *command) newComputePoolCreateCommand() *cobra.Command {
 	}
 
 	pcmd.AddCloudFlag(cmd)
-	c.addRegionFlag(cmd)
+	pcmd.AddRegionFlagFlink(cmd, c.AuthenticatedCLICommand)
 	cmd.Flags().Int32("max-cfu", 5, "Maximum number of Confluent Flink Units (CFU).")
 	pcmd.AddEnvironmentFlag(cmd, c.AuthenticatedCLICommand)
 	pcmd.AddOutputFlag(cmd)
@@ -81,14 +81,15 @@ func (c *command) computePoolCreate(cmd *cobra.Command, args []string) error {
 
 	table := output.NewTable(cmd)
 	table.Add(&computePoolOut{
-		IsCurrent:  computePool.GetId() == c.Context.GetCurrentFlinkComputePool(),
-		Id:         computePool.GetId(),
-		Name:       computePool.Spec.GetDisplayName(),
-		CurrentCfu: computePool.Status.GetCurrentCfu(),
-		MaxCfu:     computePool.Spec.GetMaxCfu(),
-		Cloud:      computePool.Spec.GetCloud(),
-		Region:     computePool.Spec.GetRegion(),
-		Status:     computePool.Status.GetPhase(),
+		IsCurrent:   computePool.GetId() == c.Context.GetCurrentFlinkComputePool(),
+		Id:          computePool.GetId(),
+		Name:        computePool.Spec.GetDisplayName(),
+		Environment: computePool.Spec.Environment.GetId(),
+		CurrentCfu:  computePool.Status.GetCurrentCfu(),
+		MaxCfu:      computePool.Spec.GetMaxCfu(),
+		Cloud:       computePool.Spec.GetCloud(),
+		Region:      computePool.Spec.GetRegion(),
+		Status:      computePool.Status.GetPhase(),
 	})
 	return table.Print()
 }
