@@ -15,7 +15,7 @@ func (c *command) newComputePoolListCommand() *cobra.Command {
 		RunE:  c.computePoolList,
 	}
 
-	c.addRegionFlag(cmd)
+	pcmd.AddRegionFlagFlink(cmd, c.AuthenticatedCLICommand)
 	pcmd.AddEnvironmentFlag(cmd, c.AuthenticatedCLICommand)
 	pcmd.AddOutputFlag(cmd)
 
@@ -41,14 +41,15 @@ func (c *command) computePoolList(cmd *cobra.Command, _ []string) error {
 	list := output.NewList(cmd)
 	for _, computePool := range computePools {
 		list.Add(&computePoolOut{
-			IsCurrent:  computePool.GetId() == c.Context.GetCurrentFlinkComputePool(),
-			Id:         computePool.GetId(),
-			Name:       computePool.Spec.GetDisplayName(),
-			CurrentCfu: computePool.Status.GetCurrentCfu(),
-			MaxCfu:     computePool.Spec.GetMaxCfu(),
-			Cloud:      computePool.Spec.GetCloud(),
-			Region:     computePool.Spec.GetRegion(),
-			Status:     computePool.Status.GetPhase(),
+			IsCurrent:   computePool.GetId() == c.Context.GetCurrentFlinkComputePool(),
+			Id:          computePool.GetId(),
+			Name:        computePool.Spec.GetDisplayName(),
+			Environment: computePool.Spec.Environment.GetId(),
+			CurrentCfu:  computePool.Status.GetCurrentCfu(),
+			MaxCfu:      computePool.Spec.GetMaxCfu(),
+			Cloud:       computePool.Spec.GetCloud(),
+			Region:      computePool.Spec.GetRegion(),
+			Status:      computePool.Status.GetPhase(),
 		})
 	}
 	return list.Print()
