@@ -86,7 +86,7 @@ func (c *aclCommand) delete(cmd *cobra.Command, _ []string) error {
 	if count > 1 {
 		promptMsg = fmt.Sprintf(pacl.DeleteACLConfirmMsg, resource.Plural(resource.ACL))
 	}
-	if err := deletion.ConfirmDeletionYesNo(cmd, promptMsg); err != nil {
+	if err := deletion.ConfirmPromptYesOrNo(cmd, promptMsg); err != nil {
 		return err
 	}
 
