@@ -49,11 +49,12 @@ func (c *clusterCommand) newCreateCommand() *cobra.Command {
 	}
 
 	pcmd.AddCloudFlag(cmd)
-	pcmd.AddRegionFlag(cmd, c.AuthenticatedCLICommand)
+	pcmd.AddRegionFlagKafka(cmd, c.AuthenticatedCLICommand)
 	pcmd.AddAvailabilityFlag(cmd)
 	pcmd.AddTypeFlag(cmd)
 	cmd.Flags().Int("cku", 0, `Number of Confluent Kafka Units (non-negative). Required for Kafka clusters of type "dedicated".`)
 	pcmd.AddByokKeyFlag(cmd, c.AuthenticatedCLICommand)
+	pcmd.AddNetworkFlag(cmd, c.AuthenticatedCLICommand)
 	pcmd.AddContextFlag(cmd, c.CLICommand)
 	pcmd.AddEnvironmentFlag(cmd, c.AuthenticatedCLICommand)
 	pcmd.AddOutputFlag(cmd)
@@ -138,6 +139,17 @@ func (c *clusterCommand) create(cmd *cobra.Command, args []string) error {
 		setClusterConfigCku(&createCluster, int32(cku))
 	}
 
+	if cmd.Flags().Changed("network") {
+		network, err := cmd.Flags().GetString("network")
+		if err != nil {
+			return err
+		}
+		if clusterType != skuDedicated {
+			return errors.NewErrorWithSuggestions("the `--network` flag can only be used when creating a dedicated Kafka cluster", "Specify a dedicated cluster with `--type dedicated`.")
+		}
+		createCluster.Spec.Network = &cmkv2.EnvScopedObjectReference{Id: network}
+	}
+
 	kafkaCluster, httpResp, err := c.V2Client.CreateKafkaCluster(createCluster)
 	if err != nil {
 		return catchClusterConfigurationNotValidError(err, httpResp, cloud, region)
