@@ -45,6 +45,7 @@ var (
 		"stag.cpdev.cloud",
 		"confluent.cloud",
 		"premium-oryx.gcp.priv.cpdev.cloud",
+		"confluentgov-internal.com",
 	}
 	regularOrgContextState = &ContextState{
 		Auth: &AuthConfig{
@@ -987,6 +988,20 @@ func TestConfig_IsCloud_False(t *testing.T) {
 	}
 }
 
+func TestHasGovHostname(t *testing.T) {
+	cfg := &Config{
+		Contexts:       map[string]*Context{"context": {PlatformName: "https://confluentgov-internal.com"}},
+		CurrentContext: "context",
+	}
+	require.True(t, cfg.HasGovHostname())
+
+	cfg = &Config{
+		Contexts:       map[string]*Context{"context": {PlatformName: "https://confluent.cloud"}},
+		CurrentContext: "context",
+	}
+	require.False(t, cfg.HasGovHostname())
+}
+
 func TestConfig_IsCloudLoginAllowFreeTrialEnded_True(t *testing.T) {
 	for _, platform := range cloudPlatforms {
 		// test case: org not suspended
