@@ -44,7 +44,7 @@ func New(fields ...Field) *Form {
 func (f *Form) Prompt(prompt Prompt) error {
 	for i := 0; i < len(f.Fields); i++ {
 		field := f.Fields[i]
-		output.Print(field.String())
+		output.Print(false, field.String())
 
 		val, err := field.read(prompt)
 		if err != nil {
@@ -54,7 +54,7 @@ func (f *Form) Prompt(prompt Prompt) error {
 		res, err := field.validate(val)
 		if err != nil {
 			if fmt.Sprintf(errors.InvalidInputFormatErrorMsg, val, field.ID) == err.Error() {
-				output.ErrPrintln(err)
+				output.ErrPrintf(false, "Error: %v\n", err)
 				i-- // re-prompt on invalid regex
 				continue
 			}
@@ -73,20 +73,20 @@ func (f *Form) Prompt(prompt Prompt) error {
 func ConfirmEnter() error {
 	// This function prevents echoing of user input instead of displaying text or *'s by using
 	// term.ReadPassword so that the CLI will appear to wait until 'enter' or 'Ctrl-C' are entered.
-	output.Print("Press enter to continue or Ctrl-C to cancel:")
+	output.Print(false, "Press enter to continue or Ctrl-C to cancel:")
 
 	if _, err := term.ReadPassword(int(os.Stdin.Fd())); err != nil {
 		return err
 	}
 	// Warning: do not remove this print line; it prevents an unexpected interaction with browser.OpenUrl causing pages to open in the background
-	output.Print("\n")
+	output.Println(false, "")
 
 	return nil
 }
 
 func checkRequiredYes(field Field, res any) bool {
 	if field.IsYesOrNo && field.RequireYes && !res.(bool) {
-		output.Println("You must accept to continue. To abandon flow, use Ctrl-C.")
+		output.Println(false, "You must accept to continue. To abandon flow, use Ctrl-C.")
 		return true
 	}
 	return false
