@@ -24,6 +24,7 @@ const (
 	CustomConnectorPlugin           = "custom connector plugin"
 	ConsumerShare                   = "consumer share"
 	Context                         = "context"
+	Dek                             = "DEK"
 	Environment                     = "environment"
 	Flink                           = "flink"
 	FlinkComputePool                = "Flink compute pool"
@@ -34,6 +35,7 @@ const (
 	IpGroup                         = "IP group"
 	IpFilter                        = "IP filter"
 	KafkaCluster                    = "Kafka cluster"
+	Kek                             = "KEK"
 	KsqlCluster                     = "KSQL cluster"
 	MirrorTopic                     = "mirror topic"
 	Network                         = "network"
