@@ -4,13 +4,13 @@ func (s *CLITestSuite) TestEnvironment() {
 	tests := []CLITest{
 		{args: "environment list", fixture: "environment/1.golden", login: "cloud"},
 		{args: "environment use env-595", fixture: "environment/2.golden"},
-		{args: "environment update env-595 --name new-other-name", fixture: "environment/3.golden"},
+		{args: "environment update env-595 --name new-other-name --governance-package advanced", fixture: "environment/3.golden"},
 		{args: "environment list", fixture: "environment/4.golden"},
 		{args: "environment list -o json", fixture: "environment/5.golden"},
 		{args: "environment list -o yaml", fixture: "environment/6.golden"},
 		{args: "environment use env-dne", fixture: "environment/7.golden", exitCode: 1},
 		{args: "environment create saucayyy", fixture: "environment/8.golden"},
-		{args: "environment create saucayyy -o json", fixture: "environment/9.golden"},
+		{args: "environment create saucayyy -o json --governance-package advanced", fixture: "environment/9.golden"},
 		{args: "environment create saucayyy -o yaml", fixture: "environment/10.golden"},
 	}
 
