@@ -4,9 +4,6 @@ import (
 	"encoding/json"
 	"fmt"
 	"os"
-	"path/filepath"
-	"runtime"
-	"strings"
 	"testing"
 
 	"github.com/stretchr/testify/require"
@@ -18,12 +15,9 @@ import (
 	"github.com/confluentinc/cli/v3/pkg/config"
 	"github.com/confluentinc/cli/v3/pkg/errors"
 	"github.com/confluentinc/cli/v3/pkg/netrc"
-	"github.com/confluentinc/cli/v3/pkg/utils"
 )
 
 var (
-	urlPlaceHolder          = "<URL_PLACEHOLDER>"
-	passwordPlaceholder     = "<PASSWORD_PLACEHOLDER>"
 	loggedInAsOutput        = fmt.Sprintf(errors.LoggedInAsMsg, "good@user.com")
 	loggedInAsWithOrgOutput = fmt.Sprintf(errors.LoggedInAsMsgWithOrg, "good@user.com", "abc-123", "Confluent")
 	loggedInEnvOutput       = "Using environment \"env-596\".\n"
@@ -165,31 +159,19 @@ func (s *CLITestSuite) TestLogin_UseKafkaAuthKafkaErrors() {
 func (s *CLITestSuite) TestLogin_SaveUsernamePassword() {
 	tests := []struct {
 		isCloud  bool
-		want     string
 		loginURL string
-		bin      string
 	}{
 		{
 			true,
-			"login/config-save-ccloud-username-password.golden",
 			s.TestBackend.GetCloudUrl(),
-			testBin,
 		},
 		{
 			false,
-			"login/config-save-mds-username-password.golden",
 			s.TestBackend.GetMdsUrl(),
-			testBin,
 		},
 	}
 
-	_, callerFileName, _, ok := runtime.Caller(0)
-	if !ok {
-		s.T().Fatalf("problems recovering caller information")
-	}
-
 	for _, test := range tests {
-		configFile := filepath.Join(os.Getenv("HOME"), ".confluent", "config.json")
 		// run the login command with --save flag and check output
 		var env []string
 		if test.isCloud {
@@ -199,7 +181,7 @@ func (s *CLITestSuite) TestLogin_SaveUsernamePassword() {
 		}
 
 		// TODO: add save test using stdin input
-		output := runCommand(s.T(), test.bin, env, "login -vvv --save --url "+test.loginURL, 0, "")
+		output := runCommand(s.T(), testBin, env, "login -vvv --save --url "+test.loginURL, 0, "")
 		if test.isCloud {
 			s.Contains(output, loggedInAsWithOrgOutput)
 			s.Contains(output, loggedInEnvOutput)
@@ -207,19 +189,14 @@ func (s *CLITestSuite) TestLogin_SaveUsernamePassword() {
 			s.Contains(output, loggedInAsOutput)
 		}
 
-		// check netrc file result
-		got, err := os.ReadFile(configFile)
+		got, err := os.ReadFile(config.GetDefaultFilename())
 		s.NoError(err)
-		wantFile := filepath.Join(filepath.Dir(callerFileName), "fixtures", "output", test.want)
+
+		cfg := &config.Config{}
+		err = json.Unmarshal(got, cfg)
 		s.NoError(err)
-		wantBytes, err := os.ReadFile(wantFile)
-		s.NoError(err)
-		want := strings.ReplaceAll(string(wantBytes), urlPlaceHolder, test.loginURL)
-		data := config.Config{}
-		err = json.Unmarshal(got, &data)
-		s.NoError(err)
-		want = strings.ReplaceAll(want, passwordPlaceholder, data.SavedCredentials["login-good@user.com-"+test.loginURL].EncryptedPassword)
-		require.Contains(s.T(), utils.NormalizeNewLines(string(got)), utils.NormalizeNewLines(want))
+
+		require.NotNil(s.T(), cfg.SavedCredentials["login-good@user.com-"+test.loginURL])
 	}
 	_ = os.Remove(netrc.IntegrationTestFile)
 }
@@ -251,7 +228,7 @@ func (s *CLITestSuite) TestLogin_UpdateNetrcPassword() {
 			env = []string{fmt.Sprintf("%s=good@user.com", auth.ConfluentPlatformUsername), fmt.Sprintf("%s=pass1", auth.ConfluentPlatformPassword)}
 		}
 
-		configFile := filepath.Join(os.Getenv("HOME"), ".confluent", "config.json")
+		configFile := config.GetDefaultFilename()
 		old, err := os.ReadFile(configFile)
 		s.NoError(err)
 		oldData := config.Config{}
@@ -333,18 +310,17 @@ func (s *CLITestSuite) TestLogin_SsoCodeInvalidFormat() {
 func (s *CLITestSuite) TestLogin_RemoveSlashFromPlatformName() {
 	resetConfiguration(s.T(), false)
 
-	configFile := filepath.Join(os.Getenv("HOME"), ".confluent", "config.json")
-
 	args := fmt.Sprintf("login --url %s/", s.TestBackend.GetCloudUrl())
 	env := []string{fmt.Sprintf("%s=good@user.com", pauth.ConfluentCloudEmail), fmt.Sprintf("%s=pass1", pauth.ConfluentCloudPassword)}
 
 	_ = runCommand(s.T(), testBin, env, args, 0, "")
 
-	got, err := os.ReadFile(configFile)
-	s.NoError(err)
-	data := config.Config{}
-	err = json.Unmarshal(got, &data)
+	got, err := os.ReadFile(config.GetDefaultFilename())
 	s.NoError(err)
 
-	s.Equal(s.TestBackend.GetCloudUrl(), data.Context().PlatformName)
+	cfg := &config.Config{}
+	err = json.Unmarshal(got, cfg)
+	s.NoError(err)
+
+	s.Equal(s.TestBackend.GetCloudUrl(), cfg.Context().PlatformName)
 }
